==> ejc-businessplan-impl-3.0.0-20220225.080726-13-sources.jar: com/ejianc/business/change/bean/ChangebusinessplaneffectdetailEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目商务策划效果变更子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_businessplan_businessplaneffectdetail")
public class ChangebusinessplaneffectdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 商务策划效果变更主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="category_and_name")
    private java.lang.String categoryAndName; // 类别及项目名称
    @TableField(value="initiate_reason")
    private java.lang.String initiateReason; // 立项理由及依据
    @TableField(value="initiate_date")
    private java.util.Date initiateDate; // 立项时间
    @TableField(value="cost_estimate")
    private java.math.BigDecimal costEstimate; // 成本估算(成本分析)(元)
    @TableField(value="report_amount")
    private java.math.BigDecimal reportAmount; // 上报金额(元)
    @TableField(value="target_amount")
    private java.math.BigDecimal targetAmount; // 策划目标金额(元)
    @TableField(value="complete_amount")
    private java.math.BigDecimal completeAmount; // 已完成目标金额(元)
    @TableField(value="estimate_profits")
    private java.math.BigDecimal estimateProfits; // 预计利润(元)
    @TableField(value="proposed_complete_time")
    private java.util.Date proposedCompleteTime; // 拟完成时间节点
    @TableField(value="complete_time")
    private java.util.Date completeTime; // 完成时间
    @TableField(value="supporting_details")
    private java.lang.String supportingDetails; // 证明资料明细
    @TableField(value="report_to_thismonth_progress")
    private java.math.BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    @TableField(value="first_responsible_person")
    private java.lang.String firstResponsiblePerson; // 第一责任人
    @TableField(value="main_responsible_person")
    private java.lang.String mainResponsiblePerson; // 主要负责人
    @TableField(value="final_complete_time")
    private java.util.Date finalCompleteTime; // (最后)完成时间
    @TableField(value="attention")
    private java.lang.String attention; // 推荐情况、存在问题、注意事项
    @TableField(value="supervision_not_reported_money")
    private java.math.BigDecimal supervisionNotReportedMoney; // 监理未上报金额
    @TableField(value="supervision_not_reported_time")
    private java.util.Date supervisionNotReportedTime; // 监理未上报预计上报时间
    @TableField(value="supervision_reported_money")
    private java.math.BigDecimal supervisionReportedMoney; // 监理已上报未批复金额
    @TableField(value="supervision_reported_time")
    private java.util.Date supervisionReportedTime; // 监理已上报未批复上报时间
    @TableField(value="supervision_approved_money")
    private java.math.BigDecimal supervisionApprovedMoney; // 监理已批复金额
    @TableField(value="supervision_approved_time")
    private java.util.Date supervisionApprovedTime; // 监理已批复上报时间
    @TableField(value="owner_not_reported_money")
    private java.math.BigDecimal ownerNotReportedMoney; // 业主未上报金额
    @TableField(value="owner_not_reported_time")
    private java.util.Date ownerNotReportedTime; // 业主未上报预计上报时间
    @TableField(value="owner_reported_money")
    private java.math.BigDecimal ownerReportedMoney; // 业主已上报未批复金额
    @TableField(value="owner_reported_time")
    private java.util.Date ownerReportedTime; // 业主已上报未批复上报时间
    @TableField(value="owner_approved_money")
    private java.math.BigDecimal ownerApprovedMoney; // 业主已批复金额
    @TableField(value="owner_approved_time")
    private java.util.Date ownerApprovedTime; // 业主已批复上报时间
    @TableField(value="approved_money")
    private java.math.BigDecimal approvedMoney; // 已批复金额
    @TableField(value="priced_money")
    private java.math.BigDecimal pricedMoney; // 已计价金额
    @TableField(value="priced_actual_money")
    private java.math.BigDecimal pricedActualMoney; // 已计价部分实际金额
    @TableField(value="priced_part_benefit")
    private java.math.BigDecimal pricedPartBenefit; // 已计价部分的效益
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    
    
    

    /**
     * 商务策划效果变更主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 商务策划效果变更主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 类别及项目名称
     */
    public java.lang.String getCategoryAndName() {
        return categoryAndName;
    }

    /**
     * 类别及项目名称
     */
    public void setCategoryAndName(java.lang.String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    /**
     * 立项理由及依据
     */
    public java.lang.String getInitiateReason() {
        return initiateReason;
    }

    /**
     * 立项理由及依据
     */
    public void setInitiateReason(java.lang.String initiateReason) {
        this.initiateReason = initiateReason;
    }
    /**
     * 立项时间
     */
    public java.util.Date getInitiateDate() {
        return initiateDate;
    }

    /**
     * 立项时间
     */
    public void setInitiateDate(java.util.Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    /**
     * 成本估算(成本分析)(元)
     */
    public java.math.BigDecimal getCostEstimate() {
        return costEstimate;
    }

    /**
     * 成本估算(成本分析)(元)
     */
    public void setCostEstimate(java.math.BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    /**
     * 上报金额(元)
     */
    public java.math.BigDecimal getReportAmount() {
        return reportAmount;
    }

    /**
     * 上报金额(元)
     */
    public void setReportAmount(java.math.BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    /**
     * 策划目标金额(元)
     */
    public java.math.BigDecimal getTargetAmount() {
        return targetAmount;
    }

    /**
     * 策划目标金额(元)
     */
    public void setTargetAmount(java.math.BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    /**
     * 已完成目标金额(元)
     */
    public java.math.BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    /**
     * 已完成目标金额(元)
     */
    public void setCompleteAmount(java.math.BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    /**
     * 预计利润(元)
     */
    public java.math.BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    /**
     * 预计利润(元)
     */
    public void setEstimateProfits(java.math.BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    /**
     * 拟完成时间节点
     */
    public java.util.Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    /**
     * 拟完成时间节点
     */
    public void setProposedCompleteTime(java.util.Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    /**
     * 完成时间
     */
    public java.util.Date getCompleteTime() {
        return completeTime;
    }

    /**
     * 完成时间
     */
    public void setCompleteTime(java.util.Date completeTime) {
        this.completeTime = completeTime;
    }
    /**
     * 证明资料明细
     */
    public java.lang.String getSupportingDetails() {
        return supportingDetails;
    }

    /**
     * 证明资料明细
     */
    public void setSupportingDetails(java.lang.String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    /**
     * 报公司截至本月进度(元)
     */
    public java.math.BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    /**
     * 报公司截至本月进度(元)
     */
    public void setReportToThismonthProgress(java.math.BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    /**
     * 第一责任人
     */
    public java.lang.String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    /**
     * 第一责任人
     */
    public void setFirstResponsiblePerson(java.lang.String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    /**
     * 主要负责人
     */
    public java.lang.String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    /**
     * 主要负责人
     */
    public void setMainResponsiblePerson(java.lang.String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    /**
     * (最后)完成时间
     */
    public java.util.Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    /**
     * (最后)完成时间
     */
    public void setFinalCompleteTime(java.util.Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    /**
     * 推荐情况、存在问题、注意事项
     */
    public java.lang.String getAttention() {
        return attention;
    }

    /**
     * 推荐情况、存在问题、注意事项
     */
    public void setAttention(java.lang.String attention) {
        this.attention = attention;
    }
    /**
     * 监理未上报金额
     */
    public java.math.BigDecimal getSupervisionNotReportedMoney() {
        return supervisionNotReportedMoney;
    }

    /**
     * 监理未上报金额
     */
    public void setSupervisionNotReportedMoney(java.math.BigDecimal supervisionNotReportedMoney) {
        this.supervisionNotReportedMoney = supervisionNotReportedMoney;
    }
    /**
     * 监理未上报预计上报时间
     */
    public java.util.Date getSupervisionNotReportedTime() {
        return supervisionNotReportedTime;
    }

    /**
     * 监理未上报预计上报时间
     */
    public void setSupervisionNotReportedTime(java.util.Date supervisionNotReportedTime) {
        this.supervisionNotReportedTime = supervisionNotReportedTime;
    }
    /**
     * 监理已上报未批复金额
     */
    public java.math.BigDecimal getSupervisionReportedMoney() {
        return supervisionReportedMoney;
    }

    /**
     * 监理已上报未批复金额
     */
    public void setSupervisionReportedMoney(java.math.BigDecimal supervisionReportedMoney) {
        this.supervisionReportedMoney = supervisionReportedMoney;
    }
    /**
     * 监理已上报未批复上报时间
     */
    public java.util.Date getSupervisionReportedTime() {
        return supervisionReportedTime;
    }

    /**
     * 监理已上报未批复上报时间
     */
    public void setSupervisionReportedTime(java.util.Date supervisionReportedTime) {
        this.supervisionReportedTime = supervisionReportedTime;
    }
    /**
     * 监理已批复金额
     */
    public java.math.BigDecimal getSupervisionApprovedMoney() {
        return supervisionApprovedMoney;
    }

    /**
     * 监理已批复金额
     */
    public void setSupervisionApprovedMoney(java.math.BigDecimal supervisionApprovedMoney) {
        this.supervisionApprovedMoney = supervisionApprovedMoney;
    }
    /**
     * 监理已批复上报时间
     */
    public java.util.Date getSupervisionApprovedTime() {
        return supervisionApprovedTime;
    }

    /**
     * 监理已批复上报时间
     */
    public void setSupervisionApprovedTime(java.util.Date supervisionApprovedTime) {
        this.supervisionApprovedTime = supervisionApprovedTime;
    }
    /**
     * 业主未上报金额
     */
    public java.math.BigDecimal getOwnerNotReportedMoney() {
        return ownerNotReportedMoney;
    }

    /**
     * 业主未上报金额
     */
    public void setOwnerNotReportedMoney(java.math.BigDecimal ownerNotReportedMoney) {
        this.ownerNotReportedMoney = ownerNotReportedMoney;
    }
    /**
     * 业主未上报预计上报时间
     */
    public java.util.Date getOwnerNotReportedTime() {
        return ownerNotReportedTime;
    }

    /**
     * 业主未上报预计上报时间
     */
    public void setOwnerNotReportedTime(java.util.Date ownerNotReportedTime) {
        this.ownerNotReportedTime = ownerNotReportedTime;
    }
    /**
     * 业主已上报未批复金额
     */
    public java.math.BigDecimal getOwnerReportedMoney() {
        return ownerReportedMoney;
    }

    /**
     * 业主已上报未批复金额
     */
    public void setOwnerReportedMoney(java.math.BigDecimal ownerReportedMoney) {
        this.ownerReportedMoney = ownerReportedMoney;
    }
    /**
     * 业主已上报未批复上报时间
     */
    public java.util.Date getOwnerReportedTime() {
        return ownerReportedTime;
    }

    /**
     * 业主已上报未批复上报时间
     */
    public void setOwnerReportedTime(java.util.Date ownerReportedTime) {
        this.ownerReportedTime = ownerReportedTime;
    }
    /**
     * 业主已批复金额
     */
    public java.math.BigDecimal getOwnerApprovedMoney() {
        return ownerApprovedMoney;
    }

    /**
     * 业主已批复金额
     */
    public void setOwnerApprovedMoney(java.math.BigDecimal ownerApprovedMoney) {
        this.ownerApprovedMoney = ownerApprovedMoney;
    }
    /**
     * 业主已批复上报时间
     */
    public java.util.Date getOwnerApprovedTime() {
        return ownerApprovedTime;
    }

    /**
     * 业主已批复上报时间
     */
    public void setOwnerApprovedTime(java.util.Date ownerApprovedTime) {
        this.ownerApprovedTime = ownerApprovedTime;
    }
    /**
     * 已批复金额
     */
    public java.math.BigDecimal getApprovedMoney() {
        return approvedMoney;
    }

    /**
     * 已批复金额
     */
    public void setApprovedMoney(java.math.BigDecimal approvedMoney) {
        this.approvedMoney = approvedMoney;
    }
    /**
     * 已计价金额
     */
    public java.math.BigDecimal getPricedMoney() {
        return pricedMoney;
    }

    /**
     * 已计价金额
     */
    public void setPricedMoney(java.math.BigDecimal pricedMoney) {
        this.pricedMoney = pricedMoney;
    }
    /**
     * 已计价部分实际金额
     */
    public java.math.BigDecimal getPricedActualMoney() {
        return pricedActualMoney;
    }

    /**
     * 已计价部分实际金额
     */
    public void setPricedActualMoney(java.math.BigDecimal pricedActualMoney) {
        this.pricedActualMoney = pricedActualMoney;
    }
    /**
     * 已计价部分的效益
     */
    public java.math.BigDecimal getPricedPartBenefit() {
        return pricedPartBenefit;
    }

    /**
     * 已计价部分的效益
     */
    public void setPricedPartBenefit(java.math.BigDecimal pricedPartBenefit) {
        this.pricedPartBenefit = pricedPartBenefit;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20220630.064344-85-sources.jar: com/ejianc/business/change/bean/ChangebusinessplaneffectdetailEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目商务策划效果变更子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_businessplan_businessplaneffectdetail")
public class ChangebusinessplaneffectdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 商务策划效果变更主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="tid")
    private java.lang.String tid;
    @TableField(value="tpid")
    private java.lang.String tpid;
    @TableField(value="category_and_name")
    private java.lang.String categoryAndName; // 类别及项目名称
    @TableField(value="initiate_reason")
    private java.lang.String initiateReason; // 立项理由及依据
    @TableField(value="initiate_date")
    private java.util.Date initiateDate; // 立项时间
    @TableField(value="cost_estimate")
    private java.math.BigDecimal costEstimate; // 成本估算(成本分析)(元)
    @TableField(value="report_amount")
    private java.math.BigDecimal reportAmount; // 上报金额(元)
    @TableField(value="target_amount")
    private java.math.BigDecimal targetAmount; // 策划目标金额(元)
    @TableField(value="complete_amount")
    private java.math.BigDecimal completeAmount; // 已完成目标金额(元)
    @TableField(value="estimate_profits")
    private java.math.BigDecimal estimateProfits; // 预计利润(元)
    @TableField(value="proposed_complete_time")
    private java.util.Date proposedCompleteTime; // 拟完成时间节点
    @TableField(value="complete_time")
    private java.util.Date completeTime; // 完成时间
    @TableField(value="supporting_details")
    private java.lang.String supportingDetails; // 证明资料明细
    @TableField(value="report_to_thismonth_progress")
    private java.math.BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    @TableField(value="first_responsible_person")
    private java.lang.String firstResponsiblePerson; // 第一责任人
    @TableField(value="main_responsible_person")
    private java.lang.String mainResponsiblePerson; // 主要负责人
    @TableField(value="final_complete_time")
    private java.util.Date finalCompleteTime; // (最后)完成时间
    @TableField(value="attention")
    private java.lang.String attention; // 推荐情况、存在问题、注意事项
    @TableField(value="supervision_not_reported_money")
    private java.math.BigDecimal supervisionNotReportedMoney; // 监理未上报金额
    @TableField(value="supervision_not_reported_time")
    private java.util.Date supervisionNotReportedTime; // 监理未上报预计上报时间
    @TableField(value="supervision_reported_money")
    private java.math.BigDecimal supervisionReportedMoney; // 监理已上报未批复金额
    @TableField(value="supervision_reported_time")
    private java.util.Date supervisionReportedTime; // 监理已上报未批复上报时间
    @TableField(value="supervision_approved_money")
    private java.math.BigDecimal supervisionApprovedMoney; // 监理已批复金额
    @TableField(value="supervision_approved_time")
    private java.util.Date supervisionApprovedTime; // 监理已批复上报时间
    @TableField(value="owner_not_reported_money")
    private java.math.BigDecimal ownerNotReportedMoney; // 业主未上报金额
    @TableField(value="owner_not_reported_time")
    private java.util.Date ownerNotReportedTime; // 业主未上报预计上报时间
    @TableField(value="owner_reported_money")
    private java.math.BigDecimal ownerReportedMoney; // 业主已上报未批复金额
    @TableField(value="owner_reported_time")
    private java.util.Date ownerReportedTime; // 业主已上报未批复上报时间
    @TableField(value="owner_approved_money")
    private java.math.BigDecimal ownerApprovedMoney; // 业主已批复金额
    @TableField(value="owner_approved_time")
    private java.util.Date ownerApprovedTime; // 业主已批复上报时间
    @TableField(value="approved_money")
    private java.math.BigDecimal approvedMoney; // 已批复金额
    @TableField(value="priced_money")
    private java.math.BigDecimal pricedMoney; // 已计价金额
    @TableField(value="priced_actual_money")
    private java.math.BigDecimal pricedActualMoney; // 已计价部分实际金额
    @TableField(value="priced_part_benefit")
    private java.math.BigDecimal pricedPartBenefit; // 已计价部分的效益
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    
    
    

    /**
     * 商务策划效果变更主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 商务策划效果变更主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 类别及项目名称
     */
    public java.lang.String getCategoryAndName() {
        return categoryAndName;
    }

    /**
     * 类别及项目名称
     */
    public void setCategoryAndName(java.lang.String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    /**
     * 立项理由及依据
     */
    public java.lang.String getInitiateReason() {
        return initiateReason;
    }

    /**
     * 立项理由及依据
     */
    public void setInitiateReason(java.lang.String initiateReason) {
        this.initiateReason = initiateReason;
    }
    /**
     * 立项时间
     */
    public java.util.Date getInitiateDate() {
        return initiateDate;
    }

    /**
     * 立项时间
     */
    public void setInitiateDate(java.util.Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    /**
     * 成本估算(成本分析)(元)
     */
    public java.math.BigDecimal getCostEstimate() {
        return costEstimate;
    }

    /**
     * 成本估算(成本分析)(元)
     */
    public void setCostEstimate(java.math.BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    /**
     * 上报金额(元)
     */
    public java.math.BigDecimal getReportAmount() {
        return reportAmount;
    }

    /**
     * 上报金额(元)
     */
    public void setReportAmount(java.math.BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    /**
     * 策划目标金额(元)
     */
    public java.math.BigDecimal getTargetAmount() {
        return targetAmount;
    }

    /**
     * 策划目标金额(元)
     */
    public void setTargetAmount(java.math.BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    /**
     * 已完成目标金额(元)
     */
    public java.math.BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    /**
     * 已完成目标金额(元)
     */
    public void setCompleteAmount(java.math.BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    /**
     * 预计利润(元)
     */
    public java.math.BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    /**
     * 预计利润(元)
     */
    public void setEstimateProfits(java.math.BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    /**
     * 拟完成时间节点
     */
    public java.util.Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    /**
     * 拟完成时间节点
     */
    public void setProposedCompleteTime(java.util.Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    /**
     * 完成时间
     */
    public java.util.Date getCompleteTime() {
        return completeTime;
    }

    /**
     * 完成时间
     */
    public void setCompleteTime(java.util.Date completeTime) {
        this.completeTime = completeTime;
    }
    /**
     * 证明资料明细
     */
    public java.lang.String getSupportingDetails() {
        return supportingDetails;
    }

    /**
     * 证明资料明细
     */
    public void setSupportingDetails(java.lang.String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    /**
     * 报公司截至本月进度(元)
     */
    public java.math.BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    /**
     * 报公司截至本月进度(元)
     */
    public void setReportToThismonthProgress(java.math.BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    /**
     * 第一责任人
     */
    public java.lang.String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    /**
     * 第一责任人
     */
    public void setFirstResponsiblePerson(java.lang.String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    /**
     * 主要负责人
     */
    public java.lang.String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    /**
     * 主要负责人
     */
    public void setMainResponsiblePerson(java.lang.String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    /**
     * (最后)完成时间
     */
    public java.util.Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    /**
     * (最后)完成时间
     */
    public void setFinalCompleteTime(java.util.Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    /**
     * 推荐情况、存在问题、注意事项
     */
    public java.lang.String getAttention() {
        return attention;
    }

    /**
     * 推荐情况、存在问题、注意事项
     */
    public void setAttention(java.lang.String attention) {
        this.attention = attention;
    }
    /**
     * 监理未上报金额
     */
    public java.math.BigDecimal getSupervisionNotReportedMoney() {
        return supervisionNotReportedMoney;
    }

    /**
     * 监理未上报金额
     */
    public void setSupervisionNotReportedMoney(java.math.BigDecimal supervisionNotReportedMoney) {
        this.supervisionNotReportedMoney = supervisionNotReportedMoney;
    }
    /**
     * 监理未上报预计上报时间
     */
    public java.util.Date getSupervisionNotReportedTime() {
        return supervisionNotReportedTime;
    }

    /**
     * 监理未上报预计上报时间
     */
    public void setSupervisionNotReportedTime(java.util.Date supervisionNotReportedTime) {
        this.supervisionNotReportedTime = supervisionNotReportedTime;
    }
    /**
     * 监理已上报未批复金额
     */
    public java.math.BigDecimal getSupervisionReportedMoney() {
        return supervisionReportedMoney;
    }

    /**
     * 监理已上报未批复金额
     */
    public void setSupervisionReportedMoney(java.math.BigDecimal supervisionReportedMoney) {
        this.supervisionReportedMoney = supervisionReportedMoney;
    }
    /**
     * 监理已上报未批复上报时间
     */
    public java.util.Date getSupervisionReportedTime() {
        return supervisionReportedTime;
    }

    /**
     * 监理已上报未批复上报时间
     */
    public void setSupervisionReportedTime(java.util.Date supervisionReportedTime) {
        this.supervisionReportedTime = supervisionReportedTime;
    }
    /**
     * 监理已批复金额
     */
    public java.math.BigDecimal getSupervisionApprovedMoney() {
        return supervisionApprovedMoney;
    }

    /**
     * 监理已批复金额
     */
    public void setSupervisionApprovedMoney(java.math.BigDecimal supervisionApprovedMoney) {
        this.supervisionApprovedMoney = supervisionApprovedMoney;
    }
    /**
     * 监理已批复上报时间
     */
    public java.util.Date getSupervisionApprovedTime() {
        return supervisionApprovedTime;
    }

    /**
     * 监理已批复上报时间
     */
    public void setSupervisionApprovedTime(java.util.Date supervisionApprovedTime) {
        this.supervisionApprovedTime = supervisionApprovedTime;
    }
    /**
     * 业主未上报金额
     */
    public java.math.BigDecimal getOwnerNotReportedMoney() {
        return ownerNotReportedMoney;
    }

    /**
     * 业主未上报金额
     */
    public void setOwnerNotReportedMoney(java.math.BigDecimal ownerNotReportedMoney) {
        this.ownerNotReportedMoney = ownerNotReportedMoney;
    }
    /**
     * 业主未上报预计上报时间
     */
    public java.util.Date getOwnerNotReportedTime() {
        return ownerNotReportedTime;
    }

    /**
     * 业主未上报预计上报时间
     */
    public void setOwnerNotReportedTime(java.util.Date ownerNotReportedTime) {
        this.ownerNotReportedTime = ownerNotReportedTime;
    }
    /**
     * 业主已上报未批复金额
     */
    public java.math.BigDecimal getOwnerReportedMoney() {
        return ownerReportedMoney;
    }

    /**
     * 业主已上报未批复金额
     */
    public void setOwnerReportedMoney(java.math.BigDecimal ownerReportedMoney) {
        this.ownerReportedMoney = ownerReportedMoney;
    }
    /**
     * 业主已上报未批复上报时间
     */
    public java.util.Date getOwnerReportedTime() {
        return ownerReportedTime;
    }

    /**
     * 业主已上报未批复上报时间
     */
    public void setOwnerReportedTime(java.util.Date ownerReportedTime) {
        this.ownerReportedTime = ownerReportedTime;
    }
    /**
     * 业主已批复金额
     */
    public java.math.BigDecimal getOwnerApprovedMoney() {
        return ownerApprovedMoney;
    }

    /**
     * 业主已批复金额
     */
    public void setOwnerApprovedMoney(java.math.BigDecimal ownerApprovedMoney) {
        this.ownerApprovedMoney = ownerApprovedMoney;
    }
    /**
     * 业主已批复上报时间
     */
    public java.util.Date getOwnerApprovedTime() {
        return ownerApprovedTime;
    }

    /**
     * 业主已批复上报时间
     */
    public void setOwnerApprovedTime(java.util.Date ownerApprovedTime) {
        this.ownerApprovedTime = ownerApprovedTime;
    }
    /**
     * 已批复金额
     */
    public java.math.BigDecimal getApprovedMoney() {
        return approvedMoney;
    }

    /**
     * 已批复金额
     */
    public void setApprovedMoney(java.math.BigDecimal approvedMoney) {
        this.approvedMoney = approvedMoney;
    }
    /**
     * 已计价金额
     */
    public java.math.BigDecimal getPricedMoney() {
        return pricedMoney;
    }

    /**
     * 已计价金额
     */
    public void setPricedMoney(java.math.BigDecimal pricedMoney) {
        this.pricedMoney = pricedMoney;
    }
    /**
     * 已计价部分实际金额
     */
    public java.math.BigDecimal getPricedActualMoney() {
        return pricedActualMoney;
    }

    /**
     * 已计价部分实际金额
     */
    public void setPricedActualMoney(java.math.BigDecimal pricedActualMoney) {
        this.pricedActualMoney = pricedActualMoney;
    }
    /**
     * 已计价部分的效益
     */
    public java.math.BigDecimal getPricedPartBenefit() {
        return pricedPartBenefit;
    }

    /**
     * 已计价部分的效益
     */
    public void setPricedPartBenefit(java.math.BigDecimal pricedPartBenefit) {
        this.pricedPartBenefit = pricedPartBenefit;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}
